Hello community,

here is the log from the commit of package aespipe for openSUSE:Factory checked 
in at 2020-07-30 10:03:22
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
Comparing /work/SRC/openSUSE:Factory/aespipe (Old)
 and      /work/SRC/openSUSE:Factory/.aespipe.new.3592 (New)
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

Package is "aespipe"

Thu Jul 30 10:03:22 2020 rev:13 rq:823520 version:2.4f

Changes:
--------
--- /work/SRC/openSUSE:Factory/aespipe/aespipe.changes  2019-11-06 
13:51:54.511883415 +0100
+++ /work/SRC/openSUSE:Factory/.aespipe.new.3592/aespipe.changes        
2020-07-30 10:04:11.211389921 +0200
@@ -1,0 +2,12 @@
+Wed Jul 29 22:24:40 UTC 2020 - Matthias Eliasson <[email protected]>
+
+- Update to 2.4f
+  * Fixed configure script mis-detection of "labels need underline
+    prefix" on Fedora. Fix from Jiri Hladky.
+  * Added configure script autodetection for x86/amd64 -fno-pie compile
+    and -no-pie linker flags. These are needed when compiler/linker
+    produces position independent executable (PIE) by default.
+- Run spec-cleaner
+- Add source verification
+
+-------------------------------------------------------------------

Old:
----
  aespipe-2.4e.tar.bz2

New:
----
  aespipe-2.4f.tar.bz2
  aespipe-2.4f.tar.bz2.sign
  aespipe.keyring

++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

Other differences:
------------------
++++++ aespipe.spec ++++++
--- /var/tmp/diff_new_pack.sNdfpY/_old  2020-07-30 10:04:13.043390164 +0200
+++ /var/tmp/diff_new_pack.sNdfpY/_new  2020-07-30 10:04:13.043390164 +0200
@@ -1,7 +1,7 @@
 #
 # spec file for package aespipe
 #
-# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
+# Copyright (c) 2020 SUSE LLC
 #
 # All modifications and additions to the file contributed by third parties
 # remain the property of their copyright owners, unless otherwise agreed
@@ -17,16 +17,17 @@
 
 
 Name:           aespipe
-Version:        2.4e
+Version:        2.4f
 Release:        0
 Summary:        AES Encrypting/Decrypting Pipe
 License:        GPL-2.0-only
-Url:            http://loop-aes.sourceforge.net/
-Source:         
http://loop-aes.sourceforge.net/aespipe/%{name}-v%{version}.tar.bz2#/%{name}-%{version}.tar.bz2
+URL:            http://loop-aes.sourceforge.net/
+Source0:        
http://loop-aes.sourceforge.net/aespipe/%{name}-v%{version}.tar.bz2#/%{name}-%{version}.tar.bz2
+Source1:        
http://loop-aes.sourceforge.net/aespipe/%{name}-v%{version}.tar.bz2.sign#/%{name}-%{version}.tar.bz2.sign
+Source2:        %{name}.keyring
 BuildRequires:  autoconf
 BuildRequires:  automake
 BuildRequires:  gpg2
-#!BuildIgnore:  gcc-PIE
 Requires:       gpg2
 
 %description
@@ -49,10 +50,10 @@
   --enable-asm=amd64 --enable-padlock --enable-intelaes \
 %endif
   --disable-silent-rules
-make %{?_smp_mflags}
+%make_build
 
 %check
-make %{?_smp_mflags} tests
+%make_build tests
 
 %install
 %make_install
@@ -63,6 +64,6 @@
 %doc ChangeLog README
 %{_bindir}/aespipe
 %{_bindir}/bz2aespipe
-%{_mandir}/man1/aespipe.1%{ext_man}
+%{_mandir}/man1/aespipe.1%{?ext_man}
 
 %changelog

++++++ aespipe-2.4e.tar.bz2 -> aespipe-2.4f.tar.bz2 ++++++
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/aespipe-v2.4e/ChangeLog new/aespipe-v2.4f/ChangeLog
--- old/aespipe-v2.4e/ChangeLog 2017-09-10 14:30:46.000000000 +0200
+++ new/aespipe-v2.4f/ChangeLog 2019-10-02 07:24:40.000000000 +0200
@@ -107,3 +107,10 @@
 
 aespipe-v2.4e     September 10 2017
     - Added workaround for gpg 2 pinentry-mode bug.
+
+aespipe-v2.4f     October 2 2019
+    - Fixed configure script mis-detection of "labels need underline
+      prefix" on Fedora. Fix from Jiri Hladky.
+    - Added configure script autodetection for x86/amd64 -fno-pie compile
+      and -no-pie linker flags. These are needed when compiler/linker
+      produces position independent executable (PIE) by default.
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/aespipe-v2.4e/README new/aespipe-v2.4f/README
--- old/aespipe-v2.4e/README    2017-09-10 14:30:46.000000000 +0200
+++ new/aespipe-v2.4f/README    2019-10-02 07:24:40.000000000 +0200
@@ -1,6 +1,6 @@
-Written by Jari Ruusu <[email protected]>, September 10 2017
+Written by Jari Ruusu <[email protected]>, October 2 2019
 
-Copyright 2002-2017 by Jari Ruusu.
+Copyright 2002-2019 by Jari Ruusu.
 Redistribution of this file is permitted under the GNU Public License.
 
 
@@ -70,12 +70,9 @@
 found.
 
 If you want to use special compiler and/or linker flags, ./configure script
-understands exported CFLAGS= and LDFLAGS= environment variables. In cases
-where compiler/linker produces position independent executable (PIE) by
-default and you want to use assembler optimized code, the PIE thingy needs
-to be disabled like this:
+understands exported CFLAGS= and LDFLAGS= environment variables. Example:
 
-    CFLAGS="-O2 -Wall -fno-pie" LDFLAGS="-no-pie" ./configure
+    CFLAGS="-O2 -Wall" LDFLAGS="" ./configure
 
 Above installs aespipe program to /usr/local/bin/ directory and man page to
 /usr/local/man/man1/ directory. If you want aespipe program installed in
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/aespipe-v2.4e/aes-amd64.S 
new/aespipe-v2.4f/aes-amd64.S
--- old/aespipe-v2.4e/aes-amd64.S       2008-11-06 08:18:00.000000000 +0100
+++ new/aespipe-v2.4f/aes-amd64.S       2019-03-11 15:39:17.000000000 +0100
@@ -255,6 +255,9 @@
        movl    %r11d,12(%r9)
        ret
 
+       .size aes_encrypt,.-aes_encrypt
+       .type aes_encrypt,@function
+
 // AES (Rijndael) Decryption Subroutine
 
 // rdi = pointer to AES context
@@ -320,6 +323,9 @@
        movl    %r11d,(%r9)
        ret
 
+       .size aes_decrypt,.-aes_decrypt
+       .type aes_decrypt,@function
+
 // AES (Rijndael) Key Schedule Subroutine
 
 // This macro performs a column mixing operation on an input 32-bit
@@ -511,6 +517,8 @@
        popfq
        ret
 
+       .size aes_set_key,.-aes_set_key
+       .type aes_set_key,@function
 
 // finite field multiplies by {02}, {04} and {08}
 
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/aespipe-v2.4e/aes-intel32.S 
new/aespipe-v2.4f/aes-intel32.S
--- old/aespipe-v2.4e/aes-intel32.S     2010-03-27 19:21:02.000000000 +0100
+++ new/aespipe-v2.4f/aes-intel32.S     2019-03-11 15:39:17.000000000 +0100
@@ -151,6 +151,9 @@
        pop %edi
        ret
 
+       .size intel_aes_cbc_encrypt,.-intel_aes_cbc_encrypt
+       .type intel_aes_cbc_encrypt,@function
+
 /*
  * void intel_aes_cbc_decrypt(const aes_context *, void *src, void *dst, 
size_t len, void *iv)
  *
@@ -390,6 +393,9 @@
        pop %edi
        ret
 
+       .size intel_aes_cbc_decrypt,.-intel_aes_cbc_decrypt
+       .type intel_aes_cbc_decrypt,@function
+
 /*
  * void intel_aes_cbc_enc_4x512(aes_context **, void *src, void *dst, void *iv)
  *
@@ -650,6 +656,9 @@
        pop %edi
        ret
 
+       .size intel_aes_cbc_enc_4x512,.-intel_aes_cbc_enc_4x512
+       .type intel_aes_cbc_enc_4x512,@function
+
 #if defined(__ELF__) && defined(SECTION_NOTE_GNU_STACK)
        .section .note.GNU-stack,"",@progbits
 #endif
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/aespipe-v2.4e/aes-intel64.S 
new/aespipe-v2.4f/aes-intel64.S
--- old/aespipe-v2.4e/aes-intel64.S     2010-03-27 19:21:27.000000000 +0100
+++ new/aespipe-v2.4f/aes-intel64.S     2019-03-11 15:39:17.000000000 +0100
@@ -140,6 +140,9 @@
        emms
        ret
 
+       .size intel_aes_cbc_encrypt,.-intel_aes_cbc_encrypt
+       .type intel_aes_cbc_encrypt,@function
+
 /*
  * void intel_aes_cbc_decrypt(const aes_context *, void *src, void *dst, 
size_t len, void *iv)
  *
@@ -399,6 +402,9 @@
        emms
        ret
 
+       .size intel_aes_cbc_decrypt,.-intel_aes_cbc_decrypt
+       .type intel_aes_cbc_decrypt,@function
+
 /*
  * void intel_aes_cbc_enc_4x512(aes_context **, void *src, void *dst, void *iv)
  *
@@ -644,6 +650,9 @@
        emms
        ret
 
+       .size intel_aes_cbc_enc_4x512,.-intel_aes_cbc_enc_4x512
+       .type intel_aes_cbc_enc_4x512,@function
+
 #if defined(__ELF__) && defined(SECTION_NOTE_GNU_STACK)
        .section .note.GNU-stack,"",@progbits
 #endif
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/aespipe-v2.4e/aes-x86.S new/aespipe-v2.4f/aes-x86.S
--- old/aespipe-v2.4e/aes-x86.S 2008-11-06 08:18:00.000000000 +0100
+++ new/aespipe-v2.4f/aes-x86.S 2019-03-11 15:39:17.000000000 +0100
@@ -263,6 +263,8 @@
        pop     %ebp
        ret
 
+       .size aes_encrypt,.-aes_encrypt
+       .type aes_encrypt,@function
 
 // AES (Rijndael) Decryption Subroutine
 
@@ -326,6 +328,9 @@
        pop     %ebp
        ret
 
+       .size aes_decrypt,.-aes_decrypt
+       .type aes_decrypt,@function
+
 // AES (Rijndael) Key Schedule Subroutine
 
 // input/output parameters
@@ -541,6 +546,8 @@
        popfl
        ret
 
+       .size aes_set_key,.-aes_set_key
+       .type aes_set_key,@function
 
 // finite field multiplies by {02}, {04} and {08}
 
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/aespipe-v2.4e/configure new/aespipe-v2.4f/configure
--- old/aespipe-v2.4e/configure 2017-09-10 13:52:14.000000000 +0200
+++ new/aespipe-v2.4f/configure 2019-10-02 06:52:27.000000000 +0200
@@ -5195,7 +5195,7 @@
 void ${label}(void){}
 
 _ACEOF
-if ${CC} ${CPPFLAGS} ${CFLAGS} -c conftest.c >/dev/null 2>&1 && ${NM_PROG} 
conftest.o | ${GREP} "_${label}" >/dev/null 2>&1; then
+if ${CC} ${CPPFLAGS} ${CFLAGS} -c conftest.c >/dev/null 2>&1 && ${NM_PROG} 
conftest.o | ${GREP} " _${label}" >/dev/null 2>&1; then
        { $as_echo "$as_me:${as_lineno-$LINENO}: result: yes" >&5
 $as_echo "yes" >&6; }
        $as_echo "#define USE_UNDERLINE 1" >>confdefs.h
@@ -5709,6 +5709,31 @@
 { $as_echo "$as_me:${as_lineno-$LINENO}: result: $x_enable_intelaes" >&5
 $as_echo "$x_enable_intelaes" >&6; }
 
+if test "$x_enable_x86asm" = yes -o "$x_enable_amd64asm" = yes ; then
+       { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether compiler 
understands -fno-pie -no-pie" >&5
+$as_echo_n "checking whether compiler understands -fno-pie -no-pie... " >&6; }
+       cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+       void foobar123(void){}
+
+_ACEOF
+       ${CC} ${CPPFLAGS} ${CFLAGS} -fno-pie -no-pie -c conftest.c 
>conftest.X.txt 2>&1
+       x_cc_rv=$?
+       ${GREP} "unrecognized option" conftest.X.txt >/dev/null 2>&1
+       x_grep_rv=$?
+       if test "${x_cc_rv}" = 0 -a "${x_grep_rv}" != 0 ; then
+               { $as_echo "$as_me:${as_lineno-$LINENO}: result: yes" >&5
+$as_echo "yes" >&6; }
+               CFLAGS="${CFLAGS} -fno-pie"
+               LDFLAGS="${LDFLAGS} -no-pie"
+       else
+               { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
+$as_echo "no" >&6; }
+       fi
+       rm -f conftest*
+fi
+
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking if gpg 2 bug workaround can 
be enabled" >&5
 $as_echo_n "checking if gpg 2 bug workaround can be enabled... " >&6; }
 x_gpg2buggy="no"
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/aespipe-v2.4e/configure.ac 
new/aespipe-v2.4f/configure.ac
--- old/aespipe-v2.4e/configure.ac      2017-09-10 13:25:50.000000000 +0200
+++ new/aespipe-v2.4f/configure.ac      2019-10-02 06:47:38.000000000 +0200
@@ -1,9 +1,9 @@
 dnl
 dnl  configure.ac
 dnl
-dnl  Written by Jari Ruusu, September 10 2017
+dnl  Written by Jari Ruusu, October 2 2019
 dnl
-dnl  Copyright 2002-2017 by Jari Ruusu.
+dnl  Copyright 2002-2019 by Jari Ruusu.
 dnl  Redistribution of this file is permitted under the GNU Public License.
 dnl
 
@@ -58,7 +58,7 @@
 AC_LANG_CONFTEST([AC_LANG_SOURCE([
 void ${label}(void){}
 ])])
-if ${CC} ${CPPFLAGS} ${CFLAGS} -c conftest.c >/dev/null 2>&1 && ${NM_PROG} 
conftest.o | ${GREP} "_${label}" >/dev/null 2>&1; then
+if ${CC} ${CPPFLAGS} ${CFLAGS} -c conftest.c >/dev/null 2>&1 && ${NM_PROG} 
conftest.o | ${GREP} " _${label}" >/dev/null 2>&1; then
        AC_MSG_RESULT([yes])
        AC_DEFINE([USE_UNDERLINE], [1])
 else
@@ -239,6 +239,27 @@
 fi
 AC_MSG_RESULT([$x_enable_intelaes])
 
+dnl  x86/amd64 assembler sources are not compatible with position independent 
executable.
+dnl  If possible, use -fno-pie for compiling and -no-pie for linking.
+if test "$x_enable_x86asm" = yes -o "$x_enable_amd64asm" = yes ; then
+       AC_MSG_CHECKING([whether compiler understands -fno-pie -no-pie])
+       AC_LANG_CONFTEST([AC_LANG_SOURCE([
+       void foobar123(void){}
+       ])])
+       ${CC} ${CPPFLAGS} ${CFLAGS} -fno-pie -no-pie -c conftest.c 
>conftest.X.txt 2>&1
+       x_cc_rv=$?
+       ${GREP} "unrecognized option" conftest.X.txt >/dev/null 2>&1
+       x_grep_rv=$?
+       if test "${x_cc_rv}" = 0 -a "${x_grep_rv}" != 0 ; then
+               AC_MSG_RESULT([yes])
+               CFLAGS="${CFLAGS} -fno-pie"
+               LDFLAGS="${LDFLAGS} -no-pie"
+       else
+               AC_MSG_RESULT([no])
+       fi
+       rm -f conftest*
+fi
+
 dnl  Some gpg 2 versions have buggy handling of --passphrase-fd
 dnl  when the passphrase is used to decrypt public-key encrypted
 dnl  key file. Workaround is to specify --pinentry-mode .
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/aespipe-v2.4e/md5-2x-amd64.S 
new/aespipe-v2.4f/md5-2x-amd64.S
--- old/aespipe-v2.4e/md5-2x-amd64.S    2010-04-11 12:22:26.000000000 +0200
+++ new/aespipe-v2.4f/md5-2x-amd64.S    2019-03-11 15:39:17.000000000 +0100
@@ -218,6 +218,9 @@
        pop     %rbx
        ret
 
+       .size md5_transform_CPUbyteorder_2x,.-md5_transform_CPUbyteorder_2x
+       .type md5_transform_CPUbyteorder_2x,@function
+
 #if defined(__ELF__) && defined(SECTION_NOTE_GNU_STACK)
        .section .note.GNU-stack,"",@progbits
 #endif
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/aespipe-v2.4e/md5-amd64.S 
new/aespipe-v2.4f/md5-amd64.S
--- old/aespipe-v2.4e/md5-amd64.S       2008-11-06 08:18:00.000000000 +0100
+++ new/aespipe-v2.4f/md5-amd64.S       2019-03-11 15:39:17.000000000 +0100
@@ -199,6 +199,9 @@
        addl    %edx,12(%rdi)
        ret
 
+       .size md5_transform_CPUbyteorder,.-md5_transform_CPUbyteorder
+       .type md5_transform_CPUbyteorder,@function
+
 #if defined(__ELF__) && defined(SECTION_NOTE_GNU_STACK)
        .section .note.GNU-stack,"",@progbits
 #endif
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/aespipe-v2.4e/md5-x86.S new/aespipe-v2.4f/md5-x86.S
--- old/aespipe-v2.4e/md5-x86.S 2008-11-06 08:18:00.000000000 +0100
+++ new/aespipe-v2.4f/md5-x86.S 2019-03-11 15:39:17.000000000 +0100
@@ -206,6 +206,9 @@
        pop     %ebp
        ret
 
+       .size md5_transform_CPUbyteorder,.-md5_transform_CPUbyteorder
+       .type md5_transform_CPUbyteorder,@function
+
 #if defined(__ELF__) && defined(SECTION_NOTE_GNU_STACK)
        .section .note.GNU-stack,"",@progbits
 #endif


Reply via email to
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/aespipe-v2.4e/aespipe.c new/aespipe-v2.4f/aespipe.c
--- old/aespipe-v2.4e/aespipe.c 2017-09-10 13:25:50.000000000 +0200
+++ new/aespipe-v2.4f/aespipe.c 2019-10-02 07:24:40.000000000 +0200
@@ -1,9 +1,9 @@
 /*
  *  aespipe.c
  *
  *  Written by Jari Ruusu, September 10 2017
  *
- *  Copyright 2002-2017 by Jari Ruusu.
+ *  Copyright 2002-2019 by Jari Ruusu.
  *  Redistribution of this file is permitted under the GNU Public License.
  *
  *  AES encrypting or decrypting "pipe", reads from stdin, writes to stdout
@@ -1181,7 +1181,7 @@
         if(!strcmp(*argv, "-") || (**argv != '-')) {
             usage:
             fprintf(stderr, "usage: %s [options] <inputfile >outputfile\n"
-                            "version 2.4e  Copyright (c) 2002-2017 Jari Ruusu, 
(c) 2001 Dr Brian Gladman\n"
+                            "version 2.4f  Copyright (c) 2002-2019 Jari Ruusu, 
(c) 2001 Dr Brian Gladman\n"
                             "options:  -e aes128|aes192|aes256          =  set 
@@ -1,9 +1,9 @@
  *  aespipe.c
  *
- *  Written by Jari Ruusu, September 10 2017
+ *  Written by Jari Ruusu, October 2 2019
  *
key length\n"
                             "          -H sha256|sha384|sha512|rmd160   =  set 
password hash function\n"
                             "          -d         =  decrypt\n"